.. _bfields:

#####################
Magnetic Field Models
#####################

This page documents the implemented models for the mangetic fields in different astrophysical environments
available in gammaALPs:

* :ref:`cell`: Simple cell-like models for the intergalactic and intra-cluster magnetic fields.

* :ref:`gauss`: Gaussian random magnetic field for magnetic fields in galaxy clusters.

* :ref:`struc`: Structured magnetic field inside an x-ray cavity in galaxy clusters.

* :ref:`jet`: Magnetic field models for AGN jets.

* :ref:`gmf`: Implementations of magnetic-field models of the Milky Way.


.. toctree::
   :hidden:
   :maxdepth: 1

   cell
   gauss
   struc
   jet
   gmf
